package com.bonus.zlpt.equip.mapper;

import com.bonus.zlpt.equip.api.domain.HotSearch;

import java.util.List;

/**
 * 热搜设备Mapper接口
 * 
 * @author xsheng
 * @date 2023-12-02
 */
public interface HotSearchMapper 
{
    /**
     * 查询热搜设备
     * 
     * @param id 热搜设备主键
     * @return 热搜设备
     */
    public HotSearch selectHotSearchById(Long id);

    /**
     * 查询热搜设备列表
     * 
     * @param hotSearch 热搜设备
     * @return 热搜设备集合
     */
    public List<HotSearch> selectHotSearchList(HotSearch hotSearch);

    /**
     * 新增热搜设备
     * 
     * @param hotSearch 热搜设备
     * @return 结果
     */
    public int insertHotSearch(HotSearch hotSearch);

    /**
     * 修改热搜设备
     * 
     * @param hotSearch 热搜设备
     * @return 结果
     */
    public int updateHotSearch(HotSearch hotSearch);

    public int updateHotSearchByMaId(Long maId);

    /**
     * 删除热搜设备
     * 
     * @param id 热搜设备主键
     * @return 结果
     */
    public int deleteHotSearchById(Long id);

    /**
     * 批量删除热搜设备
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteHotSearchByIds(Long[] ids);
}
